package AirplaneWithRadar.MovementStrategy;

public abstract class AbstractStrategy {
    private IMoveableObject moveableObject;
    private Status state = Status.NotInit;

    protected int FieldWidth;
    public int getFieldWidth() {
        return FieldWidth;
    }
    public void setFieldWidth(int fieldWidth) {
        FieldWidth = fieldWidth;
    }

    protected int FieldHeight;
    public int getFieldHeight() {
        return FieldHeight;
    }
    public void setFieldHeight(int fieldHeight) {
        FieldHeight = fieldHeight;
    }

    public Status GetStatus() { return state; }

    public void SetData(IMoveableObject moveableObject, int width, int height)
    {
        if (moveableObject == null)
        {
            state = Status.NotInit;
            return;
        }
        state = Status.InProgress;
        this.moveableObject = moveableObject;
        FieldWidth = width;
        FieldHeight = height;
    }

    public void MakeStep()
    {
        if (state != Status.InProgress)
        {
            return;
        }
        if (IsTargetDestinaion())
        {
            state = Status.Finish;
            return;
        }
        MoveToTarget();
    }

    protected boolean MoveLeft() {return MoveTo(Movement.Left);}

    protected boolean MoveRight() {return MoveTo(Movement.Right);}

    protected boolean MoveUp() {return MoveTo(Movement.Up);}

    protected boolean MoveDown() {return MoveTo(Movement.Down);}

    protected ObjectParameters GetObjectParameters() {
        return moveableObject != null ? moveableObject.GetObjectPosition() : null;
    }

    protected Integer GetStep()
    {
        if (state != Status.InProgress)
        {
            return null;
        }
        return moveableObject != null ? moveableObject.GetStep() : null;
    }
    protected abstract void MoveToTarget();

    protected abstract boolean IsTargetDestinaion();

    private boolean MoveTo(Movement directionType)
    {
        if (state != Status.InProgress)
        {
            return false;
        }
        if (moveableObject != null && moveableObject.CheckCanMove(directionType))
        {
            moveableObject.MoveObject(directionType);
            return true;
        }
        return false;
    }
}
