package AirplaneWithRadar;
import java.awt.*;
import java.util.Random;
public class PaintAirplaneWithRadar {
    private AirplaneWithRadarEntity airplaneWithRadarEntity;
    private int pictWidth;
    private int pictHeight;
    private int startPosX;
    private int startPosY;
    private final int planeWidth = 140;
    private final int planeHeight = 60;
    public PaintIlluminators paintIlluminators;

    public boolean Init(int speed, double weight, Color mainColor, Color additColor, boolean radarOnBoard, boolean additFuelPod, int width, int height)
    {
        if (planeWidth > width || planeHeight > height) { return false; }

        pictHeight = height;
        pictWidth = width;
        airplaneWithRadarEntity = new AirplaneWithRadarEntity();
        airplaneWithRadarEntity.Init(speed, weight, mainColor, additColor, radarOnBoard, additFuelPod);

        paintIlluminators = new PaintIlluminators();

        Random rnd = new Random();
        paintIlluminators.setCount(rnd.nextInt(6, 35));

        return true;
    }

    public void SetPosition(int x, int y)
    {
        if (x + planeWidth < pictWidth && y + planeHeight < pictHeight)
        {
            startPosX = x;
            startPosY = y;
        }
        else
        {
            if (x > pictWidth)
            {
                while (x + planeWidth > pictWidth)
                {
                    x -= 1;
                }
            }
            if (y > pictWidth)
            {
                while (y + planeHeight > pictHeight)
                {
                    y -= 1;
                }
            }
        }
    }

    public void Move(Movement dir)
    {
        if (airplaneWithRadarEntity == null)
        {
            return;
        }
        switch (dir)
        {
            case Left:
                if (startPosX - airplaneWithRadarEntity.Step > 0)
                {
                    startPosX -= (int) airplaneWithRadarEntity.Step;
                }
                break;
            case Up:
                if (startPosY - airplaneWithRadarEntity.Step > 0)
                {
                    startPosY -= (int) airplaneWithRadarEntity.Step;
                }
                break;
            case Right:
                if (startPosX + planeWidth + airplaneWithRadarEntity.Step < pictWidth)
                {
                    startPosX += (int)airplaneWithRadarEntity.Step;
                }
                break;
            case Down:
                if (startPosY + planeHeight + airplaneWithRadarEntity.Step < pictHeight)
                {
                    startPosY += (int)airplaneWithRadarEntity.Step;
                }
                break;
        }
    }
    public void DrawTransport(Graphics g)
    {
        if (airplaneWithRadarEntity == null)
        {
            return;
        }

        //основа
        g.setColor(Color.BLACK);
        g.drawLine(startPosX + planeWidth / 44, startPosY + planeHeight / 2, startPosX + planeWidth - planeWidth / 6, startPosY + planeHeight / 2);
        g.drawLine(startPosX + planeWidth / 44, startPosY + planeHeight - planeHeight / 8, startPosX + planeWidth - planeWidth / 6, startPosY + planeHeight - planeHeight / 8);
        g.setColor(airplaneWithRadarEntity.getBodyColor());
        g.fillRect(startPosX + planeWidth / 44, startPosY + planeHeight / 2, planeWidth - 2* planeWidth/11, planeHeight / 2 - planeHeight / 8);
        g.fillOval(startPosX, startPosY + planeHeight / 2, planeWidth / 24, planeHeight / 2 - planeHeight / 8);
        g.setColor(Color.BLACK);

        g.drawArc(startPosX, startPosY + planeHeight / 2, planeWidth / 24, planeHeight/2 - planeHeight / 8, 90, 180);

        DrawTriangle(g,
                startPosX + planeWidth - planeWidth / 6, startPosY + planeHeight / 2, // 1
                startPosX + planeWidth, startPosY + 5 * planeHeight / 7, // 2
                startPosX + planeWidth - planeWidth / 6, startPosY + planeHeight - planeHeight / 8); // 3

        DrawTriangle(g,
                startPosX, startPosY, // 1
                startPosX + planeWidth/4, startPosY + planeHeight/2, // 2
                startPosX, startPosY + planeHeight / 2); // 3
        g.drawLine(startPosX + planeWidth - planeWidth / 6, startPosY + 5 * planeHeight / 7,
                startPosX + planeWidth, startPosY + 5 * planeHeight / 7);
        // колеса
        g.drawLine(startPosX + planeWidth / 4, startPosY + planeHeight - planeHeight / 8,
                startPosX + planeWidth / 4, startPosY + planeHeight - planeHeight / 11);
        g.drawLine(startPosX + planeWidth - 2 * planeWidth / 9, startPosY + planeHeight - planeHeight / 8,
                startPosX + planeWidth - 2 * planeWidth / 9, startPosY + planeHeight - planeHeight / 11);
        g.drawOval(startPosX + planeWidth / 4 - planeWidth / 23, startPosY + 11 * planeHeight / 12,
                planeHeight / 12, planeHeight / 12);
        g.drawOval(startPosX + planeWidth / 4 + planeWidth / 72, startPosY + 11 * planeHeight / 12,
                planeHeight / 12, planeHeight / 12);

        g.drawOval(startPosX + planeWidth - 5 * planeWidth / 21, startPosY + 11 * planeHeight / 12,
                planeHeight / 12, planeHeight / 12);

        g.setColor(Color.BLACK);
        g.fillRoundRect(startPosX + 2*planeWidth / 9, startPosY + planeHeight / 2 + planeHeight / 7, planeWidth/2 ,planeHeight/7, 5, 5);
        g.fillRoundRect(startPosX, startPosY + planeHeight / 2 - planeHeight/9, planeWidth / 5, planeHeight / 6, 5, 5);

        if (airplaneWithRadarEntity.RadarOnBoard) {
            g.setColor(airplaneWithRadarEntity.getAdditColor());
            g.drawLine(startPosX + planeWidth / 3, startPosY + planeHeight / 2, startPosX + planeWidth / 3, startPosY + planeHeight / 3);
            g.fillArc(startPosX + planeWidth / 4, startPosY + planeHeight / 10, planeWidth / 6, planeHeight / 4, -30, -180);
        }
        if (airplaneWithRadarEntity.AdditFuelPod)
        {
            g.setColor(airplaneWithRadarEntity.getAdditColor());
            g.fillRoundRect(startPosX, startPosY + planeHeight - 2*planeHeight / 5, planeWidth / 5, planeHeight / 6, 5, 5);
        }

        paintIlluminators.drawIlluminators(g, airplaneWithRadarEntity.getAdditColor(), startPosX, startPosY);
    }

    private void DrawTriangle(Graphics g, int x1, int y1, int x2, int y2, int x3, int y3)
    {
        g.drawLine(x1, y1, x2, y2);
        g.drawLine(x2, y2, x3, y3);
        g.drawLine(x3, y3, x1, y1);
    }
}
