package AirplaneWithRadar.PaintObjects;

import AirplaneWithRadar.Entities.AirplaneEntity;
import AirplaneWithRadar.MovementStrategy.Movement;

import java.awt.*;
import java.util.Random;

public class PaintAirplane {
    public AirplaneEntity getAirplaneEntity() {
        return airplaneEntity;
    }

    private void setAirplaneEntity(AirplaneEntity airplaneEntity) {
        this.airplaneEntity = airplaneEntity;
    }

    public AirplaneEntity airplaneEntity;
    private int pictWidth;
    private int pictHeight;
    protected int startPosX;
    protected int startPosY;
    protected int planeWidth = 140;
    protected int planeHeight = 60;
    public IPaintIlluminators paintIlluminators;

    public int GetPosX() {return startPosX;}
    public int GetPosY() {return startPosY;}
    public int GetWidth() {return planeWidth;}
    public int GetHeight() {return planeHeight;}

    public boolean CanMove(Movement dir)
    {
        if (airplaneEntity == null)
        {
            return false;
        }
        switch (dir)
        {
            case Left:
                return startPosX - airplaneEntity.Step > 0;

            case Up:
                return startPosY - airplaneEntity.Step > 0;

            case Right:
                return startPosX + planeWidth + airplaneEntity.Step < pictWidth;

            case Down:
                return startPosY + planeHeight + airplaneEntity.Step < pictHeight;

            default:
                return false;
        }
    }

    public PaintAirplane(int speed, double weight, Color mainColor, int width, int height) {
        if (planeWidth > width || planeHeight > height) {
            return;
        }

        pictHeight = height;
        pictWidth = width;
        airplaneEntity = new AirplaneEntity(speed, weight, mainColor);

        Random Random = new Random();

        int paintIlluminatorsVariant = Random.nextInt(1, 4);
        switch (paintIlluminatorsVariant) {
            case 1:
                paintIlluminators = new PaintIlluminators();
                break;
            case 2:
                paintIlluminators = new PaintRectangleIlluminators();
                break;
            case 3:
                paintIlluminators = new PaintRoundedRectIlluminator();
                break;
            default:
                break;
        }
        paintIlluminators.setCount(Random.nextInt(6, 35));
    }

    protected PaintAirplane(int speed, double weight, Color bodyColor, int width, int height, int planeWidth, int planeHeight)
    {
        if (this.planeWidth > width || this.planeHeight > height) { return; }

        pictHeight = height;
        pictWidth = width;
        this.planeWidth = planeWidth;
        this.planeHeight = planeHeight;
        airplaneEntity = new AirplaneEntity(speed, weight, bodyColor);

        paintIlluminators = new PaintIlluminators();

        Random rnd = new Random();
        paintIlluminators.setCount(rnd.nextInt(6, 35));
    }
    public void SetPosition(int x, int y) {
        if (x + planeWidth < pictWidth && y + planeHeight < pictHeight) {
            startPosX = x;
            startPosY = y;
        } else {
            if (x > pictWidth) {
                while (x + planeWidth > pictWidth) {
                    x -= 1;
                }
            }
            if (y > pictWidth) {
                while (y + planeHeight > pictHeight) {
                    y -= 1;
                }
            }
        }
    }

    public void Move(Movement dir) {
        if (airplaneEntity == null) {
            return;
        }
        switch (dir) {
            case Left:
                if (startPosX - airplaneEntity.Step > 0) {
                    startPosX -= (int) airplaneEntity.Step;
                }
                break;
            case Up:
                if (startPosY - airplaneEntity.Step > 0) {
                    startPosY -= (int) airplaneEntity.Step;
                }
                break;
            case Right:
                if (startPosX + planeWidth + airplaneEntity.Step < pictWidth) {
                    startPosX += (int) airplaneEntity.Step;
                }
                break;
            case Down:
                if (startPosY + planeHeight + airplaneEntity.Step < pictHeight) {
                    startPosY += (int) airplaneEntity.Step;
                }
                break;
        }
    }

    public void DrawTransport(Graphics g) {
        if (airplaneEntity == null) {
            return;
        }

        //основа
        g.setColor(Color.BLACK);
        g.drawLine(startPosX + planeWidth / 44, startPosY + planeHeight / 2, startPosX + planeWidth - planeWidth / 6, startPosY + planeHeight / 2);
        g.drawLine(startPosX + planeWidth / 44, startPosY + planeHeight - planeHeight / 8, startPosX + planeWidth - planeWidth / 6, startPosY + planeHeight - planeHeight / 8);
        g.setColor(airplaneEntity.getBodyColor());
        g.fillRect(startPosX + planeWidth / 44, startPosY + planeHeight / 2, planeWidth - 2 * planeWidth / 11, planeHeight / 2 - planeHeight / 8);
        g.fillOval(startPosX, startPosY + planeHeight / 2, planeWidth / 24, planeHeight / 2 - planeHeight / 8);
        g.setColor(Color.BLACK);

        g.drawArc(startPosX, startPosY + planeHeight / 2, planeWidth / 24, planeHeight / 2 - planeHeight / 8, 90, 180);

        DrawTriangle(g,
                startPosX + planeWidth - planeWidth / 6, startPosY + planeHeight / 2, // 1
                startPosX + planeWidth, startPosY + 5 * planeHeight / 7, // 2
                startPosX + planeWidth - planeWidth / 6, startPosY + planeHeight - planeHeight / 8); // 3

        DrawTriangle(g,
                startPosX, startPosY, // 1
                startPosX + planeWidth / 4, startPosY + planeHeight / 2, // 2
                startPosX, startPosY + planeHeight / 2); // 3
        g.drawLine(startPosX + planeWidth - planeWidth / 6, startPosY + 5 * planeHeight / 7,
                startPosX + planeWidth, startPosY + 5 * planeHeight / 7);
        // колеса
        g.drawLine(startPosX + planeWidth / 4, startPosY + planeHeight - planeHeight / 8,
                startPosX + planeWidth / 4, startPosY + planeHeight - planeHeight / 11);
        g.drawLine(startPosX + planeWidth - 2 * planeWidth / 9, startPosY + planeHeight - planeHeight / 8,
                startPosX + planeWidth - 2 * planeWidth / 9, startPosY + planeHeight - planeHeight / 11);
        g.drawOval(startPosX + planeWidth / 4 - planeWidth / 23, startPosY + 11 * planeHeight / 12,
                planeHeight / 12, planeHeight / 12);
        g.drawOval(startPosX + planeWidth / 4 + planeWidth / 72, startPosY + 11 * planeHeight / 12,
                planeHeight / 12, planeHeight / 12);

        g.drawOval(startPosX + planeWidth - 5 * planeWidth / 21, startPosY + 11 * planeHeight / 12,
                planeHeight / 12, planeHeight / 12);

        g.setColor(Color.BLACK);
        g.fillRoundRect(startPosX + 2 * planeWidth / 9, startPosY + planeHeight / 2 + planeHeight / 7, planeWidth / 2, planeHeight / 7, 5, 5);
        g.fillRoundRect(startPosX, startPosY + planeHeight / 2 - planeHeight / 9, planeWidth / 5, planeHeight / 6, 5, 5);

        paintIlluminators.drawIlluminators(g, airplaneEntity.getBodyColor().darker(), startPosX, startPosY);
    }
    private void DrawTriangle(Graphics g, int x1, int y1, int x2, int y2, int x3, int y3)
    {
        g.drawLine(x1, y1, x2, y2);
        g.drawLine(x2, y2, x3, y3);
        g.drawLine(x3, y3, x1, y1);
    }
}
